==> hledger-1.14.2-37-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.14.2
id: hledger-1.14.2-Gv66i054Jgg5K2nLT6ssHz
key: hledger-1.14.2-Gv66i054Jgg5K2nLT6ssHz
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
abi: 1a9254d752b90dc1a623bfe416447692
exposed: True
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version
hidden-modules: Paths_hledger
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.14.2-Gv66i054Jgg5K2nLT6ssHz
depends:
    Decimal-0.5.1-ChBIp33tEXfHRJ1R2we0oH
    Diff-0.3.4-C6Bl1un4oiiBWGaHLlh5bu
    ansi-terminal-0.9.1-4EGEPOXIA9UHNrgfDydiTP base-4.12.0.0
    base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    directory-1.3.3.0 easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
    filepath-1.4.2.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskeline-0.7.4.3 hledger-lib-1.14.1-5HfOeojYT3w8oXVSvNjiyl
    lucid-2.9.11-BYlqIMcLZzb9YSgF4fRr1J
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 process-1.6.5.0
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-7fMjMkQ4P2XAjVbJqYEYiv
    split-0.2.3.3-4dhvbosBVIlDAhhwnzSbSM
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb
    temporary-1.3-5wqvMom531J6cKm3l339v terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-1qvqZt81kSY49gkPLj6it0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
    wizards-1.0.3-LeWouXF9w2V7cw8M1LVGLS
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.14.2-40-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.14.2
id: hledger-1.14.2-KbG98sOXkzS7XzloW6nWYs
key: hledger-1.14.2-KbG98sOXkzS7XzloW6nWYs
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
abi: edd7ac081ccdda208077e9f8e2dd7f0b
exposed: True
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version
hidden-modules: Paths_hledger
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.14.2-KbG98sOXkzS7XzloW6nWYs
depends:
    Decimal-0.5.1-KsfV51rgSKfK5JhBU1efXu
    Diff-0.3.4-C6Bl1un4oiiBWGaHLlh5bu
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 data-default-0.7.1.1-5ccnbkthejE9lCjbHMgc6
    directory-1.3.3.0 easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
    filepath-1.4.2.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskeline-0.7.4.3 hledger-lib-1.14.1-FlTZne1bVCcKKYqRc8f5DI
    lucid-2.9.11-9W8MsNwB9zgDR0y6vSmGXI
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 process-1.6.5.0
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-JiO57A4gbMQ3w1iixZrO6r
    split-0.2.3.3-7iohCb3UavdKK3AcPO9G6s
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb
    temporary-1.3-FE2pFZ9dWIB3eDQ0WTL5GN terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
    wizards-1.0.3-LeWouXF9w2V7cw8M1LVGLS
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
